Class: Portal

Inherits:
Thing
  • Object
show all
Defined in:
lib/gamefic-standard/entities/portal.rb

Direct Known Subclasses

Door

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#destinationGamefic::Entity

Returns:



5
6
7
# File 'lib/gamefic-standard/entities/portal.rb', line 5

def destination
  @destination
end

#directionDirection?

Get the ordinal direction of this Portal Portals have distinct direction and name properties so games can display a bare compass direction for exits, e.g., “south” vs. “the southern door.”

A portal’s destination can also be nil, in which case it can be referenced in commands by its destination, e.g., “go to the house.”

Returns:



15
16
17
# File 'lib/gamefic-standard/entities/portal.rb', line 15

def direction
  @direction
end

Instance Method Details

#instructionObject



36
37
38
# File 'lib/gamefic-standard/entities/portal.rb', line 36

def instruction
  direction || (destination ? "to #{destination.definitely}" : name)
end

#nameObject



32
33
34
# File 'lib/gamefic-standard/entities/portal.rb', line 32

def name
  @name || (direction.nil? ? destination.name : direction.name)
end

#reverseRoom? Also known as: find_reverse

Find the portal in the destination that returns to this portal’s parent

Returns:



20
21
22
23
24
25
# File 'lib/gamefic-standard/entities/portal.rb', line 20

def reverse
  return nil if destination.nil?
  destination.children.that_are(Portal).find do |portal|
    portal.destination == parent
  end
end

#synonymsObject



40
41
42
# File 'lib/gamefic-standard/entities/portal.rb', line 40

def synonyms
  "#{super} #{@destination} #{@direction} #{!direction.nil? ? direction.synonyms : ''}"
end