Class: Gamefic::Standard::Portal

Inherits:
Thing
  • Object
show all
Defined in:
lib/gamefic/standard/entities/portal.rb

Overview

An entity that provides access from one room to another.

Direct Known Subclasses

Door

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#destinationGamefic::Entity

Returns:

  • (Gamefic::Entity)


9
10
11
# File 'lib/gamefic/standard/entities/portal.rb', line 9

def destination
  @destination
end

#directionDirection?

Get the ordinal direction of this Portal Portals have distinct direction and name properties so games can display a bare compass direction for exits, e.g., “south” vs. “the southern door.”

A portal’s destination can also be nil, in which case it can be referenced in commands by its destination, e.g., “go to the house.”

Returns:



19
20
21
# File 'lib/gamefic/standard/entities/portal.rb', line 19

def direction
  @direction
end

Instance Method Details

#instructionObject



41
42
43
# File 'lib/gamefic/standard/entities/portal.rb', line 41

def instruction
  direction || (destination ? "to #{destination.definitely}" : name)
end

#nameObject



37
38
39
# File 'lib/gamefic/standard/entities/portal.rb', line 37

def name
  @name || direction&.name || destination.name
end

#reverseRoom? Also known as: find_reverse

Find the portal in the destination that returns to this portal’s parent

Returns:



24
25
26
27
28
29
30
# File 'lib/gamefic/standard/entities/portal.rb', line 24

def reverse
  return nil if destination.nil?

  destination.children.that_are(Portal).find do |portal|
    portal.destination == parent
  end
end

#synonymsObject



45
46
47
# File 'lib/gamefic/standard/entities/portal.rb', line 45

def synonyms
  "#{super} #{@destination} #{@direction} #{!direction.nil? ? direction.synonyms : ''}"
end