Class: Gamefic::Standard::Scenery

Inherits:
Thing
  • Object
show all
Defined in:
lib/gamefic/standard/entities/scenery.rb

Overview

Scenery is an entity that is not itemized by default. They’re typically used to provide a description for objects that can be observed but do not respond to any other interactions.

Direct Known Subclasses

Rubble

Instance Attribute Summary

Attributes included from Standardized

#itemized, #locale_description, #portable

Method Summary

Methods included from Standardized

#attached=, #attached?, #itemized?, #parent=, #portable?, #room